<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ko">
  <context>
    <name>ConfigDialog</name>
    <message>
      <location filename="../config.py" line="86" />
      <source>Using configuration file at:</source>
      <translation>설정 파일 사용:</translation>
    </message>
    <message>
      <location filename="../config.py" line="105" />
      <source>Behavior</source>
      <translation>동작</translation>
    </message>
    <message>
      <location filename="../config.py" line="106" />
      <source>Automatically save documents</source>
      <translation>자동으로 문서 저장</translation>
    </message>
    <message>
      <location filename="../config.py" line="107" />
      <source>Automatically open last documents on startup</source>
      <translation>시작할 때 마지막 문서 자동으로 열기</translation>
    </message>
    <message>
      <location filename="../config.py" line="108" />
      <source>Number of recent documents</source>
      <translation>최근 사용한 문서 수</translation>
    </message>
    <message>
      <location filename="../config.py" line="109" />
      <source>Restore window geometry</source>
      <translation>창 크기 복원</translation>
    </message>
    <message>
      <location filename="../config.py" line="110" />
      <source>Default preview state</source>
      <translation>기본 미리보기 상태</translation>
    </message>
    <message>
      <location filename="../config.py" line="111" />
      <source>Open external links in ReText window</source>
      <translation>ReText 창에서 외부 링크 열기</translation>
    </message>
    <message>
      <location filename="../config.py" line="112" />
      <source>Markdown syntax extensions (comma-separated)</source>
      <translation>Markdown 구문 확장(쉼표로 구분)</translation>
    </message>
    <message>
      <location filename="../config.py" line="114" />
      <source>Enable synchronized scrolling for Markdown</source>
      <translation>Markdown에 동기화된 스크롤 사용</translation>
    </message>
    <message>
      <location filename="../config.py" line="179" />
      <location filename="../config.py" line="118" />
      <source>Editor</source>
      <translation>편집기</translation>
    </message>
    <message>
      <location filename="../config.py" line="119" />
      <source>Highlight current line</source>
      <translation>현재 라인 강조 표시</translation>
    </message>
    <message>
      <location filename="../config.py" line="120" />
      <source>Show line numbers</source>
      <translation>라인 번호 보이기</translation>
    </message>
    <message>
      <location filename="../config.py" line="121" />
      <source>Line numbers are relative to current line</source>
      <translation>라인 번호는 현재 줄에 상대적입니다</translation>
    </message>
    <message>
      <location filename="../config.py" line="122" />
      <source>Tab key inserts spaces</source>
      <translation>탭 키를 공백으로 삽입</translation>
    </message>
    <message>
      <location filename="../config.py" line="123" />
      <source>Tabulation width</source>
      <translation>표 너비</translation>
    </message>
    <message>
      <location filename="../config.py" line="124" />
      <source>Draw vertical line at column</source>
      <translation>컬럼에 수직선 그리기</translation>
    </message>
    <message>
      <location filename="../config.py" line="125" />
      <source>Enable soft wrap</source>
      <translation>소프트 랩 활성화</translation>
    </message>
    <message>
      <location filename="../config.py" line="126" />
      <source>Show document stats</source>
      <translation>문서 상태 표시</translation>
    </message>
    <message>
      <location filename="../config.py" line="127" />
      <source>Ordered list mode</source>
      <translation>정렬된 목록 모드</translation>
    </message>
    <message>
      <location filename="../config.py" line="129" />
      <source>Interface</source>
      <translation>인터페이스</translation>
    </message>
    <message>
      <location filename="../config.py" line="130" />
      <source>Hide toolbar</source>
      <translation>툴바 숨기기</translation>
    </message>
    <message>
      <location filename="../config.py" line="131" />
      <source>Icon theme name</source>
      <translation>아이콘 테마 이름</translation>
    </message>
    <message>
      <location filename="../config.py" line="132" />
      <source>Stylesheet file</source>
      <translation>스타일시트 파일</translation>
    </message>
    <message>
      <location filename="../config.py" line="133" />
      <source>Hide tabs bar when there is only one tab</source>
      <translation>탭이 하나만 있는 경우 탭 표시줄 숨기기</translation>
    </message>
    <message>
      <location filename="../config.py" line="134" />
      <source>Show full path in window title</source>
      <translation>창 제목에 전체 경로 표시</translation>
    </message>
    <message>
      <location filename="../config.py" line="135" />
      <source>Show directory tree</source>
      <translation>디렉토리 트리 표시</translation>
    </message>
    <message>
      <location filename="../config.py" line="136" />
      <source>Working directory</source>
      <translation>작업 데릭토리</translation>
    </message>
    <message>
      <location filename="../config.py" line="161" />
      <source>Help</source>
      <translation>도움말</translation>
    </message>
    <message>
      <location filename="../config.py" line="180" />
      <source>Live preview</source>
      <translation>실시간 미리보기</translation>
    </message>
    <message>
      <location filename="../config.py" line="181" />
      <source>Normal preview</source>
      <translation>일반 미리보기</translation>
    </message>
    <message>
      <location filename="../config.py" line="186" />
      <source>Disabled</source>
      <translation>비활성화</translation>
    </message>
    <message>
      <location filename="../config.py" line="187" />
      <source>Cursor Line</source>
      <translation>커서 라인</translation>
    </message>
    <message>
      <location filename="../config.py" line="188" />
      <source>Wrapped Line</source>
      <translation>래핑된 라인</translation>
    </message>
    <message>
      <location filename="../config.py" line="193" />
      <source>Increment</source>
      <translation>증가</translation>
    </message>
    <message>
      <location filename="../config.py" line="194" />
      <source>Repeat</source>
      <translation>반복</translation>
    </message>
  </context>
  <context>
    <name>DirectorySelectButton</name>
    <message>
      <location filename="../config.py" line="61" />
      <source>Select directory to open</source>
      <translation>불러올 디렉토리 선택</translation>
    </message>
  </context>
  <context>
    <name>EncodingDialog</name>
    <message>
      <location filename="../dialogs.py" line="63" />
      <source>Enter encoding name:</source>
      <translation>인코딩 명 입력:</translation>
    </message>
  </context>
  <context>
    <name>FileDialogButton</name>
    <message>
      <location filename="../config.py" line="35" />
      <source>(none)</source>
      <translation>(없음)</translation>
    </message>
  </context>
  <context>
    <name>FileSelectButton</name>
    <message>
      <location filename="../config.py" line="53" />
      <source>Select file to open</source>
      <translation>불러올 파일 선택</translation>
    </message>
  </context>
  <context>
    <name>InsertTableDialog</name>
    <message>
      <location filename="../tabledialog.py" line="27" />
      <source>Insert table</source>
      <translation>테이블 삽입</translation>
    </message>
    <message>
      <location filename="../tabledialog.py" line="36" />
      <source>Number of rows</source>
      <translation>행 수</translation>
    </message>
    <message>
      <location filename="../tabledialog.py" line="37" />
      <source>Number of columns</source>
      <translation>열 수</translation>
    </message>
  </context>
  <context>
    <name>LocaleDialog</name>
    <message>
      <location filename="../dialogs.py" line="43" />
      <source>Enter locale name (example: en_US)</source>
      <translation>로케일 이름 입력(예: en_US)</translation>
    </message>
    <message>
      <location filename="../dialogs.py" line="44" />
      <source>It is possible to specify multiple languages, separated by comma.</source>
      <translation>쉼표로 구분하여 여러 언어를 지정할 수 있습니다.</translation>
    </message>
    <message>
      <location filename="../dialogs.py" line="50" />
      <source>Set as default</source>
      <translation>기본값으로 설정</translation>
    </message>
  </context>
  <context>
    <name>Proxy</name>
    <message>
      <location filename="../fakevimeditor.py" line="62" />
      <source>No write since last change (add ! to override)</source>
      <translation>마지막 변경 이후 쓰기 없음(덮어쓰려면 ! 추가)</translation>
    </message>
    <message>
      <location filename="../fakevimeditor.py" line="118" />
      <source>Information</source>
      <translation>정보</translation>
    </message>
  </context>
  <context>
    <name>ReTextEdit</name>
    <message>
      <location filename="../editor.py" line="252" />
      <source>Add to dictionary</source>
      <translation>디렉토리에 추가</translation>
    </message>
    <message>
      <location filename="../editor.py" line="464" />
      <source>Save image</source>
      <translation>이미지 저장</translation>
    </message>
    <message>
      <location filename="../editor.py" line="466" />
      <source>Images (*.png *.jpg)</source>
      <translation>이미지 파일(*.png *.jpg)</translation>
    </message>
  </context>
  <context>
    <name>ReTextTab</name>
    <message>
      <location filename="../tab.py" line="174" />
      <source>New document</source>
      <translation>새 문서</translation>
    </message>
    <message>
      <location filename="../tab.py" line="179" />
      <source>Could not parse file contents, check if you have the &lt;a href="%s"&gt;necessary module&lt;/a&gt; installed!</source>
      <translation>파일 내용을 파싱할 수 없습니다,  &lt;a href="%s"&gt;필요한 모듈&lt;/a&gt;이 설치되어 있는지 확인하세요!</translation>
    </message>
    <message>
      <location filename="../tab.py" line="487" />
      <source>Create missing file?</source>
      <translation>누락된 파일을 만드시겠습니까?</translation>
    </message>
    <message>
      <location filename="../tab.py" line="488" />
      <source>The file '%s' does not exist.

Do you want to create it?</source>
      <translation>'%s' 파일이 없습니다.

파일을 생성하시겠습니까?</translation>
    </message>
    <message>
      <location filename="../tab.py" line="520" />
      <source>File could not be created</source>
      <translation>파일을 생성하지 못했습니다</translation>
    </message>
    <message>
      <location filename="../tab.py" line="521" />
      <source>Could not create file '%s': %s</source>
      <translation>'%s' 파일 생성 실패: %s</translation>
    </message>
  </context>
  <context>
    <name>ReTextWindow</name>
    <message>
      <location filename="../window.py" line="91" />
      <source>File toolbar</source>
      <translation>파일 툴바</translation>
    </message>
    <message>
      <location filename="../window.py" line="93" />
      <source>Edit toolbar</source>
      <translation>편집 툴바</translation>
    </message>
    <message>
      <location filename="../window.py" line="95" />
      <source>Search toolbar</source>
      <translation>검색 툴바</translation>
    </message>
    <message>
      <location filename="../window.py" line="99" />
      <source>New</source>
      <translation>새로 만들기</translation>
    </message>
    <message>
      <location filename="../window.py" line="101" />
      <source>Open</source>
      <translation>열기</translation>
    </message>
    <message>
      <location filename="../window.py" line="103" />
      <source>Set encoding</source>
      <translation>인코딩 설정</translation>
    </message>
    <message>
      <location filename="../window.py" line="1187" />
      <location filename="../window.py" line="106" />
      <source>Reload</source>
      <translation>다시 불러오기</translation>
    </message>
    <message>
      <location filename="../window.py" line="109" />
      <source>Save</source>
      <translation>저장</translation>
    </message>
    <message>
      <location filename="../window.py" line="112" />
      <source>Save as</source>
      <translation>다른 이름으로 저장</translation>
    </message>
    <message>
      <location filename="../window.py" line="114" />
      <source>Next tab</source>
      <translation>다음 탭</translation>
    </message>
    <message>
      <location filename="../window.py" line="116" />
      <source>Previous tab</source>
      <translation>이전 탭</translation>
    </message>
    <message>
      <location filename="../window.py" line="118" />
      <source>Close tab</source>
      <translation>탭 닫기</translation>
    </message>
    <message>
      <location filename="../window.py" line="120" />
      <source>Print</source>
      <translation>인쇄</translation>
    </message>
    <message>
      <location filename="../window.py" line="122" />
      <source>Print preview</source>
      <translation>인쇄 미리보기</translation>
    </message>
    <message>
      <location filename="../window.py" line="124" />
      <source>View HTML code</source>
      <translation>HTML 코드 보기</translation>
    </message>
    <message>
      <location filename="../window.py" line="125" />
      <source>Change editor font</source>
      <translation>편집기 폰트 변경</translation>
    </message>
    <message>
      <location filename="../window.py" line="127" />
      <source>Change preview font</source>
      <translation>미리보기 폰트 변경</translation>
    </message>
    <message>
      <location filename="../window.py" line="129" />
      <source>Find text</source>
      <translation>문자열 검색</translation>
    </message>
    <message>
      <location filename="../window.py" line="701" />
      <location filename="../window.py" line="131" />
      <source>Go to line</source>
      <translation>라인으로 이동</translation>
    </message>
    <message>
      <location filename="../window.py" line="134" />
      <source>Preview</source>
      <translation>미리보기</translation>
    </message>
    <message>
      <location filename="../window.py" line="144" />
      <source>Live preview</source>
      <translation>실시간 미리보기</translation>
    </message>
    <message>
      <location filename="../window.py" line="148" />
      <source>Insert table</source>
      <translation>테이블 삽입</translation>
    </message>
    <message>
      <location filename="../window.py" line="150" />
      <source>Table editing mode</source>
      <translation>테이블 편집 모드</translation>
    </message>
    <message>
      <location filename="../window.py" line="153" />
      <source>Insert images by file path</source>
      <translation>파일 경로로 이미지 삽입</translation>
    </message>
    <message>
      <location filename="../window.py" line="156" />
      <source>FakeVim mode</source>
      <translation>FakeVim 모드</translation>
    </message>
    <message>
      <location filename="../window.py" line="161" />
      <source>Fullscreen mode</source>
      <translation>전체화면 모드</translation>
    </message>
    <message>
      <location filename="../window.py" line="649" />
      <location filename="../window.py" line="164" />
      <source>Preferences</source>
      <translation>설정</translation>
    </message>
    <message>
      <location filename="../window.py" line="171" />
      <source>Quit</source>
      <translation>종료</translation>
    </message>
    <message>
      <location filename="../window.py" line="174" />
      <source>Undo</source>
      <translation>취소</translation>
    </message>
    <message>
      <location filename="../window.py" line="176" />
      <source>Redo</source>
      <translation>다시 실행</translation>
    </message>
    <message>
      <location filename="../window.py" line="178" />
      <source>Copy</source>
      <translation>복사</translation>
    </message>
    <message>
      <location filename="../window.py" line="180" />
      <source>Cut</source>
      <translation>잘라내기</translation>
    </message>
    <message>
      <location filename="../window.py" line="182" />
      <source>Paste</source>
      <translation>붙여넣기</translation>
    </message>
    <message>
      <location filename="../window.py" line="184" />
      <source>Paste image</source>
      <translation>이미지 붙여넣기</translation>
    </message>
    <message>
      <location filename="../window.py" line="186" />
      <source>Move line up</source>
      <translation>줄을 위로 이동</translation>
    </message>
    <message>
      <location filename="../window.py" line="188" />
      <source>Move line down</source>
      <translation>줄을 아래로 이동</translation>
    </message>
    <message>
      <location filename="../window.py" line="196" />
      <source>Enable</source>
      <translation>활성화</translation>
    </message>
    <message>
      <location filename="../window.py" line="197" />
      <source>Set locale</source>
      <translation>로케일 설정</translation>
    </message>
    <message>
      <location filename="../window.py" line="198" />
      <source>Use WebEngine (Chromium) renderer</source>
      <translation>웹엔진(Chromium) 렌더러 사용</translation>
    </message>
    <message>
      <location filename="../window.py" line="204" />
      <source>Show directory</source>
      <translation>디렉토리 보이기</translation>
    </message>
    <message>
      <location filename="../window.py" line="205" />
      <source>Next</source>
      <translation>다음</translation>
    </message>
    <message>
      <location filename="../window.py" line="207" />
      <source>Previous</source>
      <translation>이전</translation>
    </message>
    <message>
      <location filename="../window.py" line="209" />
      <source>Replace</source>
      <translation>바꾸기</translation>
    </message>
    <message>
      <location filename="../window.py" line="211" />
      <source>Replace all</source>
      <translation>모두 바꾸기</translation>
    </message>
    <message>
      <location filename="../window.py" line="214" />
      <source>Close</source>
      <translation>닫기</translation>
    </message>
    <message>
      <location filename="../window.py" line="218" />
      <source>Get help online</source>
      <translation>온라인 도움말</translation>
    </message>
    <message>
      <location filename="../window.py" line="219" />
      <source>What's new</source>
      <translation>새로운 기능</translation>
    </message>
    <message>
      <location filename="../window.py" line="220" />
      <source>About ReText</source>
      <translation>ReText 정보</translation>
    </message>
    <message>
      <location filename="../window.py" line="223" />
      <source>About Qt</source>
      <translation>Qt 정보</translation>
    </message>
    <message>
      <location filename="../window.py" line="238" />
      <source>Bold</source>
      <translation>굷게</translation>
    </message>
    <message>
      <location filename="../window.py" line="240" />
      <source>Italic</source>
      <translation>이탤릭</translation>
    </message>
    <message>
      <location filename="../window.py" line="242" />
      <source>Underline</source>
      <translation>밑줄</translation>
    </message>
    <message>
      <location filename="../window.py" line="315" />
      <location filename="../window.py" line="251" />
      <source>Formatting</source>
      <translation>포맷</translation>
    </message>
    <message>
      <location filename="../window.py" line="255" />
      <source>Symbols</source>
      <translation>심볼</translation>
    </message>
    <message>
      <location filename="../window.py" line="260" />
      <source>&amp;File</source>
      <translation>파일(&amp;F)</translation>
    </message>
    <message>
      <location filename="../window.py" line="261" />
      <source>&amp;Edit</source>
      <translation>편집(&amp;E)</translation>
    </message>
    <message>
      <location filename="../window.py" line="262" />
      <source>&amp;Help</source>
      <translation>도움말(&amp;H)</translation>
    </message>
    <message>
      <location filename="../window.py" line="265" />
      <source>Open recent</source>
      <translation>최근 파일 열기</translation>
    </message>
    <message>
      <location filename="../window.py" line="278" />
      <source>Export</source>
      <translation>내보내기</translation>
    </message>
    <message>
      <location filename="../window.py" line="303" />
      <source>Spell check</source>
      <translation>맞춤법 검사</translation>
    </message>
    <message>
      <location filename="../window.py" line="312" />
      <source>Default markup</source>
      <translation>기본 마크업</translation>
    </message>
    <message>
      <location filename="../window.py" line="360" />
      <source>Search</source>
      <translation>검색</translation>
    </message>
    <message>
      <location filename="../window.py" line="363" />
      <source>Replace with</source>
      <translation>바꿀 내용</translation>
    </message>
    <message>
      <location filename="../window.py" line="365" />
      <source>Case sensitively</source>
      <translation>대소문자 구분</translation>
    </message>
    <message>
      <location filename="../window.py" line="552" />
      <location filename="../window.py" line="506" />
      <source>New document</source>
      <translation>새 문서</translation>
    </message>
    <message>
      <location filename="../window.py" line="701" />
      <source>Type the line number</source>
      <translation>라인 번호 입력</translation>
    </message>
    <message>
      <location filename="../window.py" line="737" />
      <source>Please, save the file somewhere.</source>
      <translation>파일을 저장하세요.</translation>
    </message>
    <message>
      <location filename="../window.py" line="856" />
      <source>Select one or several files to open</source>
      <translation>불러올 하나 이상의 파일을 선택</translation>
    </message>
    <message>
      <location filename="../window.py" line="1244" />
      <location filename="../window.py" line="857" />
      <source>Supported files</source>
      <translation>지원하는 파일</translation>
    </message>
    <message>
      <location filename="../window.py" line="1244" />
      <location filename="../window.py" line="857" />
      <source>All files (*)</source>
      <translation>aㅗ든 파일(*)</translation>
    </message>
    <message>
      <location filename="../window.py" line="912" />
      <source>Plain text (*.txt)</source>
      <translation>일반 텍스트(*.txt)</translation>
    </message>
    <message>
      <location filename="../window.py" line="915" />
      <source>%s files</source>
      <comment>Example of final string: Markdown files</comment>
      <translation>%s 파일</translation>
    </message>
    <message>
      <location filename="../window.py" line="984" />
      <location filename="../window.py" line="928" />
      <source>Save file</source>
      <translation>파일 저장</translation>
    </message>
    <message>
      <location filename="../window.py" line="936" />
      <source>Cannot save to file which is open in another tab!</source>
      <translation>다른 탭에서 열린 파일을 저장할 수 없습니다</translation>
    </message>
    <message>
      <location filename="../window.py" line="974" />
      <source>Export document to ODT</source>
      <translation>문서를 ODT로 내보내기</translation>
    </message>
    <message>
      <location filename="../window.py" line="975" />
      <source>OpenDocument text files (*.odt)</source>
      <translation>OpenDocument Text 파일 (*.odt)</translation>
    </message>
    <message>
      <location filename="../window.py" line="985" />
      <source>HTML files (*.html *.htm)</source>
      <translation>HTML 파일(*.html *.htm)</translation>
    </message>
    <message>
      <location filename="../window.py" line="1005" />
      <source>Unrecognized paperSize setting "%s".</source>
      <translation>인식할 수 없는 용지 크기 설정 "%s".</translation>
    </message>
    <message>
      <location filename="../window.py" line="1020" />
      <source>Export document to PDF</source>
      <translation>문서를 PDF로 내보내기</translation>
    </message>
    <message>
      <location filename="../window.py" line="1022" />
      <source>PDF files (*.pdf)</source>
      <translation>PDF 파일(*.pdf)</translation>
    </message>
    <message>
      <location filename="../window.py" line="1046" />
      <source>Print document</source>
      <translation>문서 인쇄하기</translation>
    </message>
    <message>
      <location filename="../window.py" line="1070" />
      <source>Export document</source>
      <translation>문서 내보내기</translation>
    </message>
    <message>
      <location filename="../window.py" line="1090" />
      <source>Failed to execute the command:</source>
      <translation>명령어 실행 실패: </translation>
    </message>
    <message>
      <location filename="../window.py" line="1126" />
      <source>Alt text</source>
      <translation>대체 텍스트</translation>
    </message>
    <message>
      <location filename="../window.py" line="1127" />
      <location filename="../window.py" line="1126" />
      <source>URL</source>
      <translation>URL</translation>
    </message>
    <message>
      <location filename="../window.py" line="1127" />
      <source>Link text</source>
      <translation>링크 텍스트</translation>
    </message>
    <message>
      <location filename="../window.py" line="1168" />
      <source>This file has been deleted by other application.
Please make sure you save the file before exit.</source>
      <translation>이 파일은 다른 애플리케이션에 의해 삭제되었습니다.
종료하기 전에 파일을 저장했는지 확인하십시오.</translation>
    </message>
    <message>
      <location filename="../window.py" line="1177" />
      <source>This document has been modified by other application.
Do you want to reload the file (this will discard all your changes)?
</source>
      <translation>이 문서는 다른 응용 프로그램에서 수정되었습니다.
파일을 새로고침하시겠습니까(모든 변경사항이 삭제됩니다)?
</translation>
    </message>
    <message>
      <location filename="../window.py" line="1182" />
      <source>Automatic saving has been temporarily disabled for this tab to prevent data loss. It will be re-enabled when you reload the file or save it manually.</source>
      <translation>데이터 손실을 방지하기 위해 이 탭에 대한 자동 저장이 일시적으로 비활성화되었습니다. 파일을 다시 로드하거나 수동으로 저장하면 다시 활성화됩니다.</translation>
    </message>
    <message>
      <location filename="../window.py" line="1205" />
      <source>The document has been modified.
Do you want to save your changes?</source>
      <translation>문서가 변경되었습니다.
변경 내용을 저장하시겠습니까?</translation>
    </message>
    <message>
      <location filename="../window.py" line="1232" />
      <source>HTML code</source>
      <translation>HTML 코드</translation>
    </message>
    <message>
      <location filename="../window.py" line="1243" />
      <source>Select one or several images to open</source>
      <translation>불러올 하나 이상의 이미지 선택</translation>
    </message>
    <message>
      <location filename="../window.py" line="1264" />
      <source>ReText %s (using PyMarkups %s)</source>
      <translation>ReText %s (PyMarkups %s 사용)</translation>
    </message>
    <message>
      <location filename="../window.py" line="1265" />
      <source>Simple but powerful editor for Markdown and reStructuredText</source>
      <translation>심플하지만 강력한 Markdown과 reStructuredText용 편집기</translation>
    </message>
    <message>
      <location filename="../window.py" line="1267" />
      <source>Author: Dmitry Shachnev, 2011</source>
      <translation>저자: Dmitry Shachnev, 2011</translation>
    </message>
    <message>
      <location filename="../window.py" line="1270" />
      <source>Markdown syntax</source>
      <translation>Makrdown 구문</translation>
    </message>
    <message>
      <location filename="../window.py" line="1272" />
      <source>reStructuredText syntax</source>
      <translation>reStructuredText 구문</translation>
    </message>
  </context>
  <context>
    <name>TextInfoArea</name>
    <message>
      <location filename="../editor.py" line="659" />
      <source>%d w | %d a | %d c</source>
      <comment>count of words, alphanumeric characters, all characters</comment>
      <translation>%d w | %d a | %d c</translation>
    </message>
  </context>
  <context>
    <name>main</name>
    <message>
      <location filename="../__main__.py" line="84" />
      <source>Open the files in preview mode</source>
      <translation>미리보기 모드로 파일 열기</translation>
    </message>
    <message>
      <location filename="../__main__.py" line="86" />
      <source>Create a new window even if there is an existing one</source>
      <translation>기존 창이 있어도 새 창 만들기</translation>
    </message>
    <message>
      <location filename="../__main__.py" line="90" />
      <source>List of files to open</source>
      <translation>불러올 파일 목록</translation>
    </message>
  </context>
</TS>
